@@ -60,41 +60,55 @@ print_version_keywords_default = [u"printable version", u"версия для п
 single_page_keywords_default = [u"single page", u"одной страницей"]
 next_page_keywords_default = [u"next page"]
 
-try:
-    import html5lib
-    from html5lib import treebuilders
-
-    def parse_html(data = None, fromEncoding = None):
-        if data:
-            parser = html5lib.HTMLParser(tree=treebuilders.getTreeBuilder("beautifulsoup"))
-            return parser.parse(data, encoding = fromEncoding)
-        return BeautifulSoup()
-
-
-    def parse_html_fragment(data, fromEncoding = None):
-        parser = html5lib.HTMLParser(tree=treebuilders.getTreeBuilder("beautifulsoup"))
-        return parser.parseFragment(data)
-
-
+#try:
+#    import html5lib
+#    from html5lib import treebuilders
+#
+#    def parse_html(data = None, fromEncoding = None):
+#        if data:
+#            parser = html5lib.HTMLParser(tree=treebuilders.getTreeBuilder("beautifulsoup"))
+#            return parser.parse(data, encoding = fromEncoding)
+#        return BeautifulSoup()
+#
+#
+#    def parse_html_fragment(data, fromEncoding = None):
+#        parser = html5lib.HTMLParser(tree=treebuilders.getTreeBuilder("beautifulsoup"))
+#        return parser.parseFragment(data)
+#
+#
 #    def parse_xml(data):
 #        parser = html5lib.XMLParser(tree=treebuilders.getTreeBuilder("beautifulsoup"))
 #        return parser.parse(data)
-    def parse_xml(data):
-        return BeautifulStoneSoup(data, markupMassage = massage)
-
-except ImportError:
-    def parse_html(data = None, fromEncoding = None):
-        if data:
-            return BeautifulSoup(data, fromEncoding = fromEncoding)
-        return BeautifulSoup()
+#    def parse_xml(data):
+#        return BeautifulStoneSoup(data, markupMassage = massage)
+#
+#except ImportError:
+#    def parse_html(data = None, fromEncoding = None):
+#        if data:
+#            return BeautifulSoup(data, fromEncoding = fromEncoding)
+#        return BeautifulSoup()
+#
+#
+#    def parse_html_fragment(data, fromEncoding = None):
+#        return parse_html(data, fromEncoding = fromEncoding)
+#
+#
+#    def parse_xml(data):
+#        return BeautifulStoneSoup(data, markupMassage = massage)
 
 
-    def parse_html_fragment(data, fromEncoding = None):
-        return parse_html(data, fromEncoding = fromEncoding)
+def parse_html(data = None, fromEncoding = None):
+    if data:
+        return BeautifulSoup(data, fromEncoding = fromEncoding)
+    return BeautifulSoup()
 
 
-    def parse_xml(data):
-        return BeautifulStoneSoup(data, markupMassage = massage)
+def parse_html_fragment(data, fromEncoding = None):
+    return parse_html(data, fromEncoding = fromEncoding)
+
+
+def parse_xml(data):
+    return BeautifulStoneSoup(data, markupMassage = massage)
 
 
 def parse_date(str):
