@@ -12,7 +12,6 @@ import ConfigParser
 from datetime import date
 from datetime import timedelta
 from datetime import datetime
-import feedcircuit
 import urllib
 import webbrowser
 import glob
@@ -20,20 +19,11 @@ import shutil
 import sys
 import dbus
 from BeautifulSoup import BeautifulStoneSoup
+import feedcircuit
+from config import FeedConfig
+from config import FeedCircuitConfig
 
-version = "0.8.3"
-feed_template_default = """
-<html>
-    <head>
-        <meta http-equiv="Content-Type" content="text/html;charset=utf-8" >
-        %(style)s
-    </head>
-    <body>
-    </body>
-</html>
-"""
-feed_style_default = "<style> body, table { font-size: 15pt } </style>"
-custom_style = '<link rel="stylesheet" href="%(filename)s" type="text/css" />'
+version = "0.8.4"
 
 
 def init_osso_context():
@@ -64,16 +54,6 @@ def create_config_dir():
     return path
 
 
-def get_file_content(filename):
-    if filename:
-        f = open(filename, "r")
-        try:
-            return f.read()
-        finally:
-            f.close()
-    return None
-
-
 def save_icon(filename, icon_data):
     f = open(filename, "w")
     try:
@@ -481,13 +461,13 @@ class EditFeedsWindow(hildon.StackableWindow):
         self.delete_button.set_sensitive(len(pathes) > 0)
         self.clear_button.set_sensitive(len(pathes) > 0)
         self.up_button.set_sensitive(len(pathes) == 1 and pathes[0][0] > 0)
-        self.down_button.set_sensitive(len(pathes) == 1 and (pathes[0][0] + 1) < len(self.model.list))
+        self.down_button.set_sensitive(len(pathes) == 1 and (pathes[0][0] + 1) < len(self.model.config.list))
 
 
     def edit(self, source):
         pathes = self.view.get_selection().get_selected_rows()[1]
         if len(pathes) > 0:
-            feed_config = self.model.list[pathes[0][0]]
+            feed_config = self.model.config.list[pathes[0][0]]
             edit_window = EditWindow(self, feed_config)
             result = edit_window.run()
             if result == gtk.RESPONSE_ACCEPT:
@@ -499,13 +479,13 @@ class EditFeedsWindow(hildon.StackableWindow):
     def remove_feeds(self, feed_configs, delete):
         for feed_config in feed_configs:
             feed_config.message_count = 0
-            feed = feedcircuit.Feed(None, path = self.model.cache_path,
+            feed = feedcircuit.Feed(None, path = self.model.config.cache_path,
                 cache_path = ".cache", filename = feed_config.get_filename())
             feed.delete()
             gobject.idle_add(self.model.update, feed_config.id)
             if delete:
                 if feed_config.icon_filename:
-                    icon_filepath = os.path.join(self.model.cache_path, feed_config.icon_filename)
+                    icon_filepath = os.path.join(self.model.config.cache_path, feed_config.icon_filename)
                     if os.path.exists(icon_filepath):
                         os.remove(icon_filepath)
                 gobject.idle_add(self.model.delete, feed_config.id)
@@ -514,7 +494,7 @@ class EditFeedsWindow(hildon.StackableWindow):
     def remove_feeds_async(self, delete):
         pathes = self.view.get_selection().get_selected_rows()[1]
         if len(pathes):
-            feed_configs = map(lambda path: self.model.list[path[0]], pathes)
+            feed_configs = map(lambda path: self.model.config.list[path[0]], pathes)
             if delete:
                 message = _("Delete feeds?")
             else:
@@ -540,14 +520,14 @@ class EditFeedsWindow(hildon.StackableWindow):
         if len(pathes) > 0:
             index = pathes[0][0]
             if index > 0:
-                self.model.move(self.model.list[index].id, index - 1)
+                self.model.move(self.model.config.list[index].id, index - 1)
 
 
     def down(self, source):
         pathes = self.view.get_selection().get_selected_rows()[1]
         if len(pathes) > 0:
             index = pathes[0][0]
-            self.model.move(self.model.list[index].id, index + 2)
+            self.model.move(self.model.config.list[index].id, index + 2)
 
 
 class PickFeedsDialog(hildon.PickerDialog):
@@ -584,8 +564,8 @@ class Program:
         if not os.path.exists(self.__model.get_config_file_name()):
             self.import_opml()
 
-        if self.__model.browser:
-            webbrowser.register("FeedCircuitCustom", None, webbrowser.BackgroundBrowser(self.__model.browser.split()))
+        if self.__model.config.browser:
+            webbrowser.register("FeedCircuitCustom", None, webbrowser.BackgroundBrowser(self.__model.config.browser.split()))
 
 
         vbox = gtk.VBox()
@@ -662,7 +642,7 @@ class Program:
 
 
     def open_url(self, url, new_win):
-        if self.__model.browser:
+        if self.__model.config.browser:
             webbrowser.get("FeedCircuitCustom").open("file://" + url, new_win)
         else:
             #webbrowser.open(url, new_win)
@@ -674,10 +654,10 @@ class Program:
 
 
     def open_feed(self, feed_config):
-        path = os.path.join(self.__model.cache_path, feed_config.get_filename())
+        path = os.path.join(self.__model.config.cache_path, feed_config.get_filename())
         if os.path.exists(path):
             new_win = 0
-            if self.__model.use_new_window:
+            if self.__model.config.use_new_window:
                 new_win = 2
             self.open_url(path, new_win)
             feed_config.message_count = 0
@@ -691,7 +671,7 @@ class Program:
     def move_cache(self, from_path, to_path):
         if not os.path.exists(to_path):
             os.makedirs(to_path)
-        for feed_config in self.__model.list:
+        for feed_config in self.__model.config.list:
             filename = os.path.join(from_path, feed_config.get_filename())
             if os.path.exists(filename):
                 shutil.move(filename, os.path.join(to_path, feed_config.get_filename()))
@@ -705,7 +685,7 @@ class Program:
 
 
     def row_activated(self, source, path, view_column):
-        feed_config = self.__model.list[path[0]]
+        feed_config = self.__model.config.list[path[0]]
         self.open_feed(feed_config)
 
 
@@ -723,19 +703,19 @@ class Program:
                     discovery_thread.execute(feedcircuit.discover_feed, url)
                 if icon_filename:
                     icon_filename = uuid.uuid1().hex + icon_filename
-                    save_icon(os.path.join(self.__model.cache_path, icon_filename), icon_data)
+                    save_icon(os.path.join(self.__model.config.cache_path, icon_filename), icon_data)
             except Exception, ex:
                 error_note = hildon.Note("information", self.__window,
                     _("Cannot discover feed at given url") + "\n" + str(ex)) 
                 error_note.run()
                 error_note.destroy()
-            feed_config = FeedConfig(self.__model.cache_path, url, title, FeedConfig.mode_ommit, icon_filename)
+            feed_config = FeedConfig(url, title, FeedConfig.mode_ommit, icon_filename)
             edit_window = EditWindow(self.__window, feed_config)
             if edit_window.run() == gtk.RESPONSE_ACCEPT:
                 edit_window.update_feed()
                 self.__model.append(feed_config)
             elif icon_filename:
-                os.remove(os.path.join(self.__model.cache_path, icon_filename))
+                os.remove(os.path.join(self.__model.config.cache_path, icon_filename))
             edit_window.destroy()
         add_window.destroy()
 
@@ -743,9 +723,9 @@ class Program:
     def preferences(self, source):
         pref_window = PreferencesWindow(self.__window)
         try:
-            pref_window.path_entry.set_text(self.__model.cache_path)
-            pref_window.new_win_check.set_active(self.__model.use_new_window)
-            pref_window.refresh_interval.set_active(self.__model.is_interval)
+            pref_window.path_entry.set_text(self.__model.config.cache_path)
+            pref_window.new_win_check.set_active(self.__model.config.use_new_window)
+            pref_window.refresh_interval.set_active(self.__model.config.is_interval)
             time = self.__model.get_autorefresh_time()
             if time:
                 pref_window.autorefresh_check.set_active(True)
@@ -753,13 +733,13 @@ class Program:
             pref_window.update(None)
             if pref_window.run() == gtk.RESPONSE_ACCEPT:
                 new_path = os.path.abspath(pref_window.path_entry.get_text())
-                if new_path != self.__model.cache_path:
+                if new_path != self.__model.config.cache_path:
                     move_thread = BannerThread(self.__window, _("moving cache"))
-                    move_thread.execute(self.move_cache, self.__model.cache_path, new_path)
+                    move_thread.execute(self.move_cache, self.__model.config.cache_path, new_path)
                     self.__model.update_cache_path(new_path)
-                self.__model.use_new_window = pref_window.new_win_check.get_active()
+                self.__model.config.use_new_window = pref_window.new_win_check.get_active()
                 self.__model.set_autorefresh_time(None)
-                self.__model.is_interval = pref_window.refresh_interval.get_active()
+                self.__model.config.is_interval = pref_window.refresh_interval.get_active()
                 if pref_window.autorefresh_check.get_active():
                     self.__model.set_autorefresh_time(pref_window.time_selector.get_time())
                 self.schedule_next_update()
@@ -793,7 +773,7 @@ class Program:
                             if os.path.exists(icon_file_src):
                                 icon_file_name = uuid.uuid1().hex + icon_file
                                 shutil.copy(icon_file_src,
-                                    os.path.join(self.__model.cache_path, icon_file_name))
+                                    os.path.join(self.__model.config.cache_path, icon_file_name))
                     else:
                         try:
                             discovery_thread = BannerThread(self.__window, _("Importing feeds"))
@@ -801,14 +781,13 @@ class Program:
                                 discovery_thread.execute(feedcircuit.get_feed_details, outline["xmlurl"])
                             if icon_file_name:
                                 icon_file_name = uuid.uuid1().hex + icon_file_name
-                                save_icon(os.path.join(self.__model.cache_path, icon_file_name), icon_data)
+                                save_icon(os.path.join(self.__model.config.cache_path, icon_file_name), icon_data)
                         except Exception, ex:
                             error_note = hildon.Note("information", self.__window,
                                 _("Cannot discover feed at given url") + "\n" + str(ex)) 
                             error_note.run()
                             error_note.destroy()
-                    feed_config = FeedConfig(self.__model.cache_path, outline["xmlurl"], outline["title"],
-                        FeedConfig.mode_ommit, icon_file_name)
+                    feed_config = FeedConfig(outline["xmlurl"], outline["title"], FeedConfig.mode_ommit, icon_file_name)
                     self.__model.append(feed_config)
             finally:
                 f.close()
@@ -844,7 +823,7 @@ class Program:
                 f.write('<opml version="1.0">\n')
                 f.write('<head/>\n')
                 f.write('<body>\n')
-                for feed_config in self.__model.list:
+                for feed_config in self.__model.config.list:
                     title = feed_config.name.replace("<", "&lt;").replace(">", "&gt;")
                     for url in feed_config.url.split(" "):
                         f.write('<outline title="%s" description="%s" xmlUrl="%s" /> \n' %
@@ -866,32 +845,6 @@ class Program:
         dialog.destroy()
 
 
-    def get_file_name(self, id, suffix):
-        filename = os.path.join(self.__model.config_path, id + "." + suffix)
-        if os.path.exists(filename):
-            return filename
-        filename = os.path.join(self.__model.config_path, suffix)
-        if os.path.exists(filename):
-            return filename
-        return None
-
-    
-    def get_templates(self, id):
-        item = get_file_content(self.get_file_name(id, "item.template.html"))
-        update = get_file_content(self.get_file_name(id, "update.template.html"))
-        feed = get_file_content(self.get_file_name(id, "feed.template.html"))
-        page = get_file_content(self.get_file_name(id, "page.template.html"))
-        if not feed:
-            style_filename = self.get_file_name(id, "style.css")
-            if style_filename:
-                feed = feed_template_default % {"style": custom_style % {"filename": style_filename}}
-            else:
-                feed = feed_template_default % {"style": feed_style_default}
-            if not page:
-                page = feed
-        return (item, update, feed, page)
-
-
     def save_log(self):
         try:
             f = open(os.path.join(self.__model.config_path, "refresh.log"), "w")
@@ -961,7 +914,7 @@ class Program:
                 urls = feed_config.get_urls()
                 url_count = len(urls)
                 feed_count = len(feed_configs)
-                (item_t, update_t, feed_t, page_t) = self.get_templates(feed_config.id)
+                (item_t, update_t, feed_t, page_t) = feed_config.get_templates(self.__model.config_path)
                 title = None
                 if url_count == 1:
                     title = feed_config.name
@@ -976,7 +929,7 @@ class Program:
                             if feed_config.days_to_keep:
                                 del_before = date.today() - timedelta(feed_config.days_to_keep)
                                 clear_cache = False
-                            feed = feedcircuit.Feed(url = url, path = self.__model.cache_path, cache_path = ".cache",
+                            feed = feedcircuit.Feed(url = url, path = self.__model.config.cache_path, cache_path = ".cache",
                                 title = title, filename = feed_config.get_filename(),
                                 callback = self.callback,
                                 delete_before_date = del_before, always_clear_cache = clear_cache,
@@ -989,7 +942,7 @@ class Program:
                                 reformatter_url = feed_config.reformatter_url,
                                 content_kwargs = feed_config.get_content_kwargs(),
                                 ignore_images = feed_config.ignore_images,
-                                new_window = self.__model.use_new_window,
+                                new_window = self.__model.config.use_new_window,
                                 feed_item_template = item_t, feed_update_template = update_t,
                                 page_template = page_t, feed_template = feed_t)
                             feed.update()
@@ -1024,7 +977,7 @@ class Program:
 
 
     def refresh(self, source):
-        connect_and_exec(False, None, self.update_feeds_async, list(self.__model.list))
+        connect_and_exec(False, None, self.update_feeds_async, list(self.__model.config.list))
 
 
     def refresh_selected(self, source):
@@ -1035,7 +988,7 @@ class Program:
             if result == gtk.RESPONSE_OK:
                 pathes = picker_dialog.get_selector().get_selected_rows(0)
                 connect_and_exec(False, None, self.update_feeds_async,
-                    map(lambda path: self.__model.list[path[0]], pathes))
+                    map(lambda path: self.__model.config.list[path[0]], pathes))
         finally:
             picker_dialog.destroy()
 
@@ -1047,7 +1000,7 @@ class Program:
         time = self.__model.get_autorefresh_time()
         if time:
             now = datetime.now()
-            if self.__model.is_interval:
+            if self.__model.config.is_interval:
                 delta = timedelta(hours = time[0], minutes = time[1])
             else:
                 next_time = datetime(now.year, now.month, now.day, time[0], time[1], 0)
@@ -1060,8 +1013,8 @@ class Program:
 
     def auto_refresh(self):
         try:
-            connect_and_exec(True, self.__model.connection_id,
-                self.update_feeds_async, list(self.__model.list))
+            connect_and_exec(True, self.__model.config.connection_id,
+                self.update_feeds_async, list(self.__model.config.list))
         finally:
             self.schedule_next_update()
 
@@ -1070,146 +1023,6 @@ class Program:
         win = EditFeedsWindow(self.__model)
 
 
-class ConfigParserEx(ConfigParser.SafeConfigParser):
-
-
-    def get_default(self, section, name, default):
-        if self.has_option(section, name):
-            return self.get(section, name)
-        return default
-
-
-    def getint_default(self, section, name, default):
-        if self.has_option(section, name):
-            return self.getint(section, name)
-        return default
-
-
-    def getboolean_default(self, section, name, default):
-        if self.has_option(section, name):
-            return self.getboolean(section, name)
-        return default
-
-
-    def set(self, section, option, value):
-        val = value
-        if val:
-            val = val.replace("%", "%%")
-        ConfigParser.SafeConfigParser.set(self, section, option, val)
-
-class FeedConfig:
-
-
-    mode_ommit = 0
-    mode_cache = 1
-    mode_inline = 2
-
-
-    def __init__(self, cache_path, url, name, mode, icon_filename,
-        days_to_keep = 7, include = "", exclude = "", message_count = 0,
-        content_tag = "", reformatter_url = "", checked = False,
-        ignore_images = False, id = None,
-        print_version_keywords = feedcircuit.print_version_keywords_default,
-        single_page_keywords = feedcircuit.single_page_keywords_default,
-        next_page_keywords = feedcircuit.next_page_keywords_default):
-        self.id = id
-        if not self.id:
-            self.id = uuid.uuid1().hex
-        self.cache_path = cache_path
-        self.url = url
-        self.name = name
-        self.mode = mode
-        self.days_to_keep = days_to_keep
-        self.include = include
-        self.exclude = exclude
-        self.icon_filename = icon_filename
-        self.message_count = message_count
-        self.reformatter_url = reformatter_url
-        self.content_tag = content_tag
-        self.print_version_keywords = print_version_keywords
-        self.single_page_keywords = single_page_keywords
-        self.next_page_keywords = next_page_keywords
-        self.ignore_images = ignore_images
-        self.icon = None
-        self.iter = None
-        self.ord_num = 0
-        self.checked = checked
-
-
-    def get_icon(self):
-        if not self.icon:
-            if self.icon_filename:
-                icon_filepath = os.path.join(self.cache_path, self.icon_filename)
-                if os.path.exists(icon_filepath):
-                    self.icon = gtk.gdk.pixbuf_new_from_file(icon_filepath)
-                    if self.icon.get_height() > 48:
-                        self.icon = self.icon.scale_simple(
-                            self.icon.get_width() * 48 / self.icon.get_height(), 48, gtk.gdk.INTERP_BILINEAR)
-        return self.icon
-
-
-    def get_filename(self):
-        return self.id + ".html"
-
-    def get_time(self):
-        filename = os.path.join(self.cache_path, self.get_filename())
-        if os.path.exists(filename):
-            return datetime.fromtimestamp(os.path.getmtime(filename)).strftime("%c")
-        return ""
-
-
-    def get_markup(self):
-        result = "\n" + self.get_time()
-        if self.message_count:
-            result = "<b>" + self.name + " (" + str(self.message_count) + ")</b>" + result
-        else:
-            result = self.name + result
-        return result
-
-
-    def get_print_version_keywords_string(self):
-        return ",".join(self.print_version_keywords)
-
-
-    def set_print_version_keywords_string(self, keywords):
-        self.print_version_keywords = [str.strip().lower() for str in keywords.split(",")]
-
-
-    def get_single_page_keywords_string(self):
-        return ",".join(self.single_page_keywords)
-
-
-    def set_single_page_keywords_string(self, keywords):
-        self.single_page_keywords = [str.strip().lower() for str in keywords.split(",")]
-
-
-    def get_next_page_keywords_string(self):
-        return ",".join(self.next_page_keywords)
-
-
-    def set_next_page_keywords_string(self, keywords):
-        self.next_page_keywords = [str.strip().lower() for str in keywords.split(",")]
-
-
-    def get_content_kwargs(self):
-        result = {}
-        if self.content_tag:
-            parts = self.content_tag.split(" ")
-            if len(parts):
-                result["name"] = parts[0]
-                result["attrs"] = {}
-                for part in parts[1:]:
-                    name_val = part.split("=")
-                    if len(name_val) == 2:
-                        result["attrs"][name_val[0]] = \
-                            name_val[1].replace('"', "").replace("&quot;", '"')
-        return result
-
-
-    def get_urls(self):
-        return filter(len, [str.strip() for str in self.url.split(" ")])
-
-
 class FeedListModel(gtk.GenericTreeModel):
 
 
@@ -1217,10 +1030,41 @@ class FeedListModel(gtk.GenericTreeModel):
         gtk.GenericTreeModel.__init__(self)
         self.column_types = (gtk.gdk.Pixbuf, str, str, gobject.TYPE_BOOLEAN,
             str, str, int)
-        self.list = []
         self.map = {}
+        self.icons = {}
         self.config_path = config_path
-        self.load_config()
+        self.config = FeedCircuitConfig(self.get_config_file_name())
+        self.rebuild_map()
+
+
+    def get_feed_icon(self, feed_config):
+        icon = self.icons.get(feed_config.id)
+        if not icon:
+            if feed_config.icon_filename:
+                icon_filepath = os.path.join(self.config.cache_path, feed_config.icon_filename)
+                if os.path.exists(icon_filepath):
+                    icon = gtk.gdk.pixbuf_new_from_file(icon_filepath)
+                    if icon.get_height() > 48:
+                        icon = icon.scale_simple(
+                            icon.get_width() * 48 / icon.get_height(), 48, gtk.gdk.INTERP_BILINEAR)
+                    self.icons[feed_config.id] = icon
+        return icon
+
+
+    def get_feed_time(self, feed_config):
+        filename = os.path.join(self.config.cache_path, feed_config.get_filename())
+        if os.path.exists(filename):
+            return datetime.fromtimestamp(os.path.getmtime(filename)).strftime("%c")
+        return ""
+
+
+    def get_feed_markup(self, feed_config):
+        result = "\n" + self.get_feed_time(feed_config)
+        if feed_config.message_count:
+            result = "<b>" + feed_config.name.replace("&", "&amp;") + " (" + str(feed_config.message_count) + ")</b>" + result
+        else:
+            result = feed_config.name.replace("&", "&amp;") + result
+        return result
 
 
     def on_get_flags(self):
@@ -1236,8 +1080,8 @@ class FeedListModel(gtk.GenericTreeModel):
 
 
     def on_get_iter(self, path):
-        if path[0] < len(self.list):
-            return self.list[path[0]].id
+        if path[0] < len(self.config.list):
+            return self.config.list[path[0]].id
         return None
 
 
@@ -1248,15 +1092,15 @@ class FeedListModel(gtk.GenericTreeModel):
     def on_get_value(self, rowref, column):
         if self.map.has_key(rowref):
             if column is 0:
-                return self.list[self.map[rowref]].get_icon()
+                return self.get_feed_icon(self.config.list[self.map[rowref]])
             elif column is 1:
-                return self.list[self.map[rowref]].get_markup()
+                return self.get_feed_markup(self.config.list[self.map[rowref]])
             elif column is 2:
-                return self.list[self.map[rowref]].get_time()
+                return self.get_feed_time(self.config.list[self.map[rowref]])
             elif column is 3:
-                return self.list[self.map[rowref]].checked
+                return self.config.list[self.map[rowref]].checked
             elif column is 4:
-                return self.list[self.map[rowref]].name
+                return self.config.list[self.map[rowref]].name
             elif column is 5:
                 return gtk.STOCK_EDIT # edit feed icon
             elif column is 6:
@@ -1265,15 +1109,15 @@ class FeedListModel(gtk.GenericTreeModel):
 
     def on_iter_next(self, rowref):
         index = self.map[rowref] + 1
-        if index < len(self.list):
-            return self.list[index].id
+        if index < len(self.config.list):
+            return self.config.list[index].id
         return None
 
 
     def on_iter_children(self, rowref):
         if rowref:
             return None
-        return self.list[0].id
+        return self.config.list[0].id
 
 
     def on_iter_has_child(self, rowref):
@@ -1287,12 +1131,12 @@ class FeedListModel(gtk.GenericTreeModel):
     def on_iter_n_children(self, rowref):
         if rowref:
             return 0
-        return len(self.list)
+        return len(self.config.list)
 
 
     def on_iter_nth_child(self, rowref, n):
-        if not rowref and n < len(self.list):
-            return self.list[n].id
+        if not rowref and n < len(self.config.list):
+            return self.config.list[n].id
         return None
 
 
@@ -1300,103 +1144,22 @@ class FeedListModel(gtk.GenericTreeModel):
         return os.path.join(self.config_path, "config")
 
 
-    def load_config(self):
-        parser = ConfigParserEx()
-        parser.read([self.get_config_file_name()])
-        self.cache_path = parser.get_default("global", "cache path", self.config_path)
-        self.use_new_window = parser.getboolean_default("global", "use new window", False)
-        self.show_banner = parser.getboolean_default("global", "show banner", False)
-        self.autorefresh_time = parser.get_default("global", "autorefresh time", "")
-        self.connection_id = parser.get_default("global", "connection id", "")
-        self.autorefresh_checked = parser.getboolean_default("global", "autorefresh checked", False)
-        self.is_interval = parser.getboolean_default("global", "is interval", False)
-        self.browser = parser.get_default("global", "browser", "")
-        for section in parser.sections():
-            if section != "global":
-                feed_config = FeedConfig(
-                    self.cache_path,
-                    parser.get(section, "url"),
-                    parser.get(section, "name"),
-                    parser.getint_default(section, "mode", FeedConfig.mode_ommit),
-                    parser.get_default(section, "icon", ""),
-                    parser.getint_default(section, "days", 7),
-                    parser.get_default(section, "include", ""),
-                    parser.get_default(section, "exclude", ""),
-                    parser.getint_default(section, "message count", 0),
-                    parser.get_default(section, "content tag", ""),
-                    parser.get_default(section, "reformatter url", ""),
-                    parser.getboolean_default(section, "checked", False),
-                    parser.getboolean_default(section, "ignore images", False),
-                    section)
-                feed_config.ord_num = parser.getint_default(section, "order number", 0)
-                if parser.has_option(section, "print version keywords"):
-                    feed_config.set_print_version_keywords_string(
-                        parser.get(section, "print version keywords"))
-                if parser.has_option(section, "single page keywords"):
-                    feed_config.set_single_page_keywords_string(
-                        parser.get(section, "single page keywords"))
-                if parser.has_option(section, "next page keywords"):
-                    feed_config.set_next_page_keywords_string(
-                        parser.get(section, "next page keywords"))
-                self.list.append(feed_config)
-        self.list.sort(lambda f1, f2: f1.ord_num.__cmp__(f2.ord_num))
-        self.rebuild_map()
-
-
-    def save_config(self):
-        f = open(os.path.join(self.config_path, "config"), "w")
-        try:
-            parser = ConfigParserEx()
-            parser.add_section("global")
-            parser.set("global", "cache path", self.cache_path)
-            parser.set("global", "use new window", str(self.use_new_window))
-            parser.set("global", "show banner", str(self.show_banner))
-            parser.set("global", "autorefresh time", self.autorefresh_time)
-            parser.set("global", "connection id", self.connection_id)
-            parser.set("global", "autorefresh checked", str(self.autorefresh_checked))
-            parser.set("global", "is interval", str(self.is_interval))
-            parser.set("global", "browser", self.browser)
-            i = 0
-            for feed_config in self.list:
-                parser.add_section(feed_config.id)
-                parser.set(feed_config.id, "url", feed_config.url)
-                parser.set(feed_config.id, "name", feed_config.name)
-                parser.set(feed_config.id, "mode", str(feed_config.mode))
-                parser.set(feed_config.id, "days", str(feed_config.days_to_keep))
-                parser.set(feed_config.id, "include", feed_config.include)
-                parser.set(feed_config.id, "exclude", feed_config.exclude)
-                parser.set(feed_config.id, "icon", feed_config.icon_filename)
-                parser.set(feed_config.id, "message count", str(feed_config.message_count))
-                parser.set(feed_config.id, "content tag", feed_config.content_tag)
-                parser.set(feed_config.id, "reformatter url", feed_config.reformatter_url)
-                parser.set(feed_config.id, "checked", str(feed_config.checked))
-                parser.set(feed_config.id, "ignore images", str(feed_config.ignore_images))
-                parser.set(feed_config.id, "order number", str(i))
-                parser.set(feed_config.id, "print version keywords", feed_config.get_print_version_keywords_string())
-                parser.set(feed_config.id, "single page keywords", feed_config.get_single_page_keywords_string())
-                parser.set(feed_config.id, "next page keywords", feed_config.get_next_page_keywords_string())
-                i += 1
-            parser.write(f)
-        finally:
-            f.close()
-
-
     def get_autorefresh_time(self):
-        if self.autorefresh_time:
-            tuple = self.autorefresh_time.split(":")
+        if self.config.autorefresh_time:
+            tuple = self.config.autorefresh_time.split(":")
             return (int(tuple[0]), int(tuple[1]))
 
 
     def set_autorefresh_time(self, time):
-        self.autorefresh_time = ""
+        self.config.autorefresh_time = ""
         if (time):
-            self.autorefresh_time = "%d:%d" % (time[0], time[1])
+            self.config.autorefresh_time = "%d:%d" % (time[0], time[1])
 
 
     def rebuild_map(self):
         self.map.clear()
-        for i in range(len(self.list)):
-            self.map[self.list[i].id] = i
+        for i in range(len(self.config.list)):
+            self.map[self.config.list[i].id] = i
 
     def update(self, rowref):
         index = self.map[rowref]
@@ -1411,53 +1174,55 @@ class FeedListModel(gtk.GenericTreeModel):
 
     def delete(self, rowref):
         index = self.map[rowref]
-        del self.list[index]
+        del self.config.list[index]
         self.rebuild_map()
         self.row_deleted((index,))
         self.save_config()
 
 
     def append(self, feed_config):
-        index = len(self.list)
+        index = len(self.config.list)
         self.map[feed_config.id] = index
-        self.list.append(feed_config)
+        self.config.list.append(feed_config)
         self.row_inserted((index,), self.get_iter((index,)))
         self.save_config()
 
 
     def update_cache_path(self, cache_path):
-        self.cache_path = cache_path
-        for feed_config in self.list:
-            feed_config.cache_path = cache_path
+        self.config.cache_path = cache_path
 
 
     def move(self, id, pos):
         before_id = None
-        if pos >= 0 and pos < len(self.list):
-            before_id = self.list[pos].id
+        if pos >= 0 and pos < len(self.config.list):
+            before_id = self.config.list[pos].id
         if before_id == id:
             return
-        old_order = [f.id for f in self.list]
+        old_order = [f.id for f in self.config.list]
         index = self.map[id]
-        feed_config = self.list[index]
-        del self.list[index]
+        feed_config = self.config.list[index]
+        del self.config.list[index]
         self.rebuild_map()
         if before_id:
-            self.list.insert(self.map[before_id], feed_config)
+            self.config.list.insert(self.map[before_id], feed_config)
         else:
-            self.list.append(feed_config)
+            self.config.list.append(feed_config)
         self.rebuild_map()
         self.rows_reordered(None, None, [self.map[id] for id in old_order])
         self.save_config()
 
 
     def toggle(self, path):
-        feed_config = self.list[path[0]]
+        feed_config = self.config.list[path[0]]
         feed_config.checked = not feed_config.checked
         self.row_changed(path, self.get_iter(path))
         self.save_config()
 
 
+    def save_config(self):
+        self.config.save()
+
+
 gtk.gdk.threads_init()
 hildon.hildon_init()
 
